@@ -4,7 +4,7 @@
 #' Retrieves the classification of Italian municipalities into six categories; classes D, E, and F are the so-called internal/inner areas; classes A, B and C are the central areas.
 #'
 #' @param autoAbort Logical. Whether to automatically abort the operation and return NULL in case of missing internet connection or server response errors. \code{FALSE} by default.
-#'
+#' @param verbose Logical. Whether to keep track of computational time. \code{TRUE} by default.
 #'
 #' @return An object of class \code{tbl_df}, \code{tbl} and \code{data.frame}.
 #'
@@ -29,25 +29,27 @@
 #'
 #' @examples
 #'
-#'
+#' \donttest{
 #' InnerAreas <- Get_InnerAreas(autoAbort = TRUE)
-#'
 #' InnerAreas[, c(1,9,13)]
+#' }
 #'
-#' @source  <https://www.istat.it/it/archivio/273176>
+#' @source  <https://www.istat.it/notizia/la-geografia-delle-aree-interne-nel-2020-vasti-territori-tra-potenzialita-e-debolezze/>
 #'
 #'
 #'
 #' @export
 
-Get_InnerAreas <- function(autoAbort = FALSE){
 
-  # This version requires readxl. Contact the developer for the version not requiring it.
+Get_InnerAreas <- function(verbose = TRUE, autoAbort = FALSE){
+
+  # This version does not require readxl to reduce the number of dependencies.
+  # For a faster version requiring it, please ask the mantainer.
   if(!Check_connection(autoAbort)) return(NULL)
 
   starttime <- Sys.time()
 
-  home.ISTAT <-"https://www.istat.it/it/archivio/273176"
+  home.ISTAT <-"https://www.istat.it/notizia/la-geografia-delle-aree-interne-nel-2020-vasti-territori-tra-potenzialita-e-debolezze/"
   homepage <- NULL
   attempt <- 0
   while(is.null(homepage) && attempt <= 10){
@@ -61,13 +63,10 @@ Get_InnerAreas <- function(autoAbort = FALSE){
     attempt <- attempt + 1
   }
   if(is.null(homepage)) return(NULL)
+
   name_pattern <- "Elenco_Comuni_Classi_di_Aree_Interne"
   link <- homepage %>% rvest::html_nodes("a") %>% rvest::html_attr("href") %>% unique()
   link <- grep(name_pattern, link, value = TRUE)
-  if(length(link) == 0L){
-    message("Inner areas data not found. We apologise for the inconvenience.")
-    return(NULL)
-  }
 
   temp <- tempdir()
   if(!dir.exists(temp)){
@@ -75,24 +74,48 @@ Get_InnerAreas <- function(autoAbort = FALSE){
   }
 
   status <- 0
+  attempt <- 0
   while(status != 200){
     base.url <- dirname(home.ISTAT)
     file.url <- xml2::url_absolute(link, base.url)
-    response <- tryCatch({
-      httr::GET(file.url, httr::write_disk(tempfile(fileext = ".xlsx")),  httr::config(timeout = 60))
-    }, error = function(e){
-      message("Error occurred during scraping, attempt repeated ... \n")
-    })
+    response <- httr::GET(file.url, httr::write_disk(tempfile(fileext = ".xlsx")),  httr::config(timeout = 60))
     status <- response$status_code
-    if(status != 200){
-      message("Operation exited with status: ", status, "; operation repeated")
-    }
-    if(is.null(response)) status <- 0
   }
 
   excel <- response$request$output$path
-  suppressMessages(
-    res <- readxl::read_excel(excel, col_names = NA, skip = 3))
+
+  utils::unzip(excel, exdir = temp)
+
+  sheet_path <- file.path(temp, "xl", "worksheets", "sheet1.xml")
+  shared_strings_path <- file.path(temp, "xl", "sharedStrings.xml")
+
+  strings0 <- xml2::read_xml(shared_strings_path)
+
+  ns <- xml2::xml_ns(strings0)
+
+  shared_strings <- strings0 %>%
+    xml2::xml_find_all(".//d1:si/d1:t", ns = ns) %>%
+    xml2::xml_text()
+
+  sheet <- xml2::read_xml(sheet_path)
+  rows <- xml2::xml_find_all(sheet, "//d1:row", ns = xml2::xml_ns(sheet))
+
+  lst <- lapply(rows, function(X){
+    cells <- xml2::xml_find_all(X, "d1:c", ns = ns)
+    strings <- as.vector(unlist(lapply(cells, function(Y) {
+      id <- xml2::xml_find_first(Y, "d1:v", ns = ns) %>%
+        xml2::xml_text()
+      if(!is.na(xml2::xml_attr(Y, "t"))){
+        return(gsub("\\s+$", "", as.character(shared_strings[as.numeric(id) + 1])))
+      } else {
+        return(id)
+      }
+    })))
+    if(length(strings) > 16) strings <- strings[c(1:16)]
+    return(strings)
+  })
+  lst <- lst[which(lapply(lst, length)==16)]
+  res <- data.frame(do.call(rbind, lst[-1]))
 
   names(res) <-
     c("Municipality_code", "Municipality_code_numeric", "Cadastral_code", "Region_code",
@@ -101,7 +124,11 @@ Get_InnerAreas <- function(autoAbort = FALSE){
       "Inner_area_code_2021_2027", "Inner_area_description_2021_2027",
       "Destination_municipality_code", "Destination_municipality_description",
       "Destination_pole_code")
-  res$Province_code <- as.numeric(substr(res$Municipality_code, 1, 3))
+
+  res <- res %>%
+    dplyr::mutate(Province_code = as.numeric(.data$Municipality_code)%/%1000) %>%
+    dplyr::mutate(Municipality_code_numeric = as.numeric(.data$Municipality_code_numeric)) %>%
+    structure(class = c("tbl_df", "tbl", "data.frame"))
 
   if(dir.exists(temp)){
     temp.contents <- list.files(temp, full.names = T)
@@ -109,7 +136,11 @@ Get_InnerAreas <- function(autoAbort = FALSE){
       unlink(temp.contents[i], recursive = TRUE)
     }
   }
+  endtime <- Sys.time()
+  if(verbose){
+    cat(paste("Time needed to download inner areas taxomony:",
+              round(difftime(endtime, starttime, units="secs"), 2), "seconds \n"  ))
+  }
+
   return(res)
 }
-
-
